tools Package
=============

:mod:`tools` Package
--------------------

.. automodule:: numba.tools
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`astformat` Module
-----------------------

.. automodule:: numba.tools.astformat
    :members:
    :undoc-members:
    :show-inheritance:

